@@ -200,71 +200,6 @@ impl NodeWriter {
         }
     }
 
-    pub fn join_graph<'p>(&mut self, request: RawProtos, py: Python<'p>) -> PyResult<&'p PyAny> {
-        let request =
-            SetGraph::decode(&mut Cursor::new(request)).expect("Error decoding arguments");
-        let Some(shard_id) = request.shard_id else {
-            return Err(PyValueError::new_err("Missing shard_id field"));
-        };
-        let Some(graph) = request.graph else {
-            return Err(PyValueError::new_err("Missing graph field"));
-        };
-        let shard = self.obtain_shard(shard_id.id.clone())?;
-        let status = shard
-            .join_relations_graph(&graph)
-            .and_then(|()| shard.get_opstatus());
-        match status {
-            Ok(mut status) => {
-                status.status = 0;
-                status.detail = "Success!".to_string();
-                Ok(PyList::new(py, status.encode_to_vec()))
-            }
-            Err(error) => {
-                let status = OpStatus {
-                    status: op_status::Status::Error as i32,
-                    detail: error.to_string(),
-                    field_count: 0_u64,
-                    shard_id: shard_id.id,
-                    ..Default::default()
-                };
-                Ok(PyList::new(py, status.encode_to_vec()))
-            }
-        }
-    }
-
-    pub fn delete_relation_nodes<'p>(
-        &mut self,
-        request: RawProtos,
-        py: Python<'p>,
-    ) -> PyResult<&'p PyAny> {
-        let request =
-            DeleteGraphNodes::decode(&mut Cursor::new(request)).expect("Error decoding arguments");
-        let Some(ref shard_id) = request.shard_id else {
-            return Err(PyValueError::new_err("Missing shard_id field"));
-        };
-        let shard = self.obtain_shard(shard_id.id.clone())?;
-        let status = shard
-            .delete_relation_nodes(&request)
-            .and_then(|()| shard.get_opstatus());
-        match status {
-            Ok(mut status) => {
-                status.status = 0;
-                status.detail = "Success!".to_string();
-                Ok(PyList::new(py, status.encode_to_vec()))
-            }
-            Err(error) => {
-                let status = OpStatus {
-                    status: op_status::Status::Error as i32,
-                    detail: error.to_string(),
-                    field_count: 0_u64,
-                    shard_id: shard_id.id.clone(),
-                    ..Default::default()
-                };
-                Ok(PyList::new(py, status.encode_to_vec()))
-            }
-        }
-    }
-
     // TODO: rename to list_vectorsets
     pub fn get_vectorset<'p>(&mut self, request: RawProtos, py: Python<'p>) -> PyResult<&'p PyAny> {
         let shard_id =
